@@ -1,6 +1,6 @@
 package Bundle::DateTime;
 
-$VERSION = 0.01;
+$VERSION = 0.02;
 
 1;
 
@@ -18,6 +18,8 @@ C<perl -MCPAN -e 'install Bundle::DateTime'>
 
 DateTime
 
+DateTime::LeapSecond - should be installed by DateTime
+
 DateTime::TimeZone - should be installed by DateTime
 
 DateTime::Set
@@ -38,18 +40,16 @@ DateTime::Format::MySQL
 
 DateTime::Format::W3CDTF
 
-DateTime::Calendar::Christian
-
 DateTime::Calendar::Julian
 
+DateTime::Calendar::Christian
+
 DateTime::Calendar::Mayan
 
 DateTime::Calendar::Pataphysical
 
 DateTime::Event::Easter
 
-DateTime::Astro::Sunrise - development release
-
 =head1 DESCRIPTION
 
 This bundle contains all modules related to the DateTime project: base
